@@ -64,9 +64,7 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
         self.version = None
 
         super(BaseKempAppliance, self).__init__(utils.DEFAULT_TLS_VERSION,
-                                                self.cert,
-                                                user=self.username,
-                                                password=self.password)
+                                                self.cert)
 
     def __repr__(self):
         return '{}:{}'.format(self.ip_address, self.port)
@@ -117,7 +115,20 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
 
     @property
     def endpoint(self):
-        return "https://{}:{}/{}".format(self.ip_address, self.port, self.access_point)
+        if self.cert:
+            return "https://{ip}:{port}/{access}".format(
+                ip=self.ip_address,
+                port=self.port,
+                access=self.access_point
+            )
+        else:
+            return "https://{user}:{pw}@{ip}:{port}/{access}".format(
+                user=self.username,
+                pw=self.password,
+                ip=self.ip_address,
+                port=self.port,
+                access=self.access_point
+            )
 
     @property
     def capabilities(self):
@@ -135,8 +146,6 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
         command = '{}/{}'.format(self.endpoint, command)
         if self.cert:
             curl.extend(['-E', self.cert])
-        else:
-            curl.extend(['-u', '{}:{}'.format(self.username, self.password)])
         curl.append(command)
         return curl
 
